@@ -7,26 +7,36 @@
 
 package Config;
 use strict;
-# use warnings; Pulls in Carp
-# use vars pulls in Carp
+use warnings;
+use vars '%Config';
+
+# Skip @Config::EXPORT because it only contains %Config, which we special
+# case below as it's not a function. @Config::EXPORT won't change in the
+# lifetime of Perl 5.
+my %Export_Cache = (myconfig => 1, config_sh => 1, config_vars => 1,
+		    config_re => 1, compile_date => 1, local_patches => 1,
+		    bincompat_options => 1, non_bincompat_options => 1,
+		    header_files => 1);
+
 @Config::EXPORT = qw(%Config);
-@Config::EXPORT_OK = qw(myconfig config_sh config_vars config_re);
+@Config::EXPORT_OK = keys %Export_Cache;
 
 # Need to stub all the functions to make code such as print Config::config_sh
 # keep working
 
-sub myconfig;
+sub bincompat_options;
+sub compile_date;
+sub config_re;
 sub config_sh;
 sub config_vars;
-sub config_re;
-
-my %Export_Cache = map {($_ => 1)} (@Config::EXPORT, @Config::EXPORT_OK);
-
-our %Config;
+sub header_files;
+sub local_patches;
+sub myconfig;
+sub non_bincompat_options;
 
 # Define our own import method to avoid pulling in the full Exporter:
 sub import {
-    my $pkg = shift;
+    shift;
     @_ = @Config::EXPORT unless @_;
 
     my @funcs = grep $_ ne '%Config', @_;
@@ -35,8 +45,8 @@ sub import {
     no strict 'refs';
     my $callpkg = caller(0);
     foreach my $func (@funcs) {
-	die sprintf qq{"%s" is not exported by the %s module\n},
-	    $func, __PACKAGE__ unless $Export_Cache{$func};
+	die qq{"$func" is not exported by the Config module\n}
+	    unless $Export_Cache{$func};
 	*{$callpkg.'::'.$func} = \&{$func};
     }
 
@@ -44,21 +54,20 @@ sub import {
     return;
 }
 
-die "Perl lib version (5.10.1) doesn't match executable version ($])"
+die "Perl lib version (5.14.2) doesn't match executable '$0' version ($])"
     unless $^V;
 
-$^V eq 5.10.1
-    or die "Perl lib version (5.10.1) doesn't match executable version (" .
+$^V eq 5.14.2
+    or die "Perl lib version (5.14.2) doesn't match executable '$0' version (" .
 	sprintf("v%vd",$^V) . ")";
 
 sub FETCH {
     my($self, $key) = @_;
 
     # check for cached value (which may be undef so we use exists not defined)
-    return $self->{$key} if exists $self->{$key};
-
-    return $self->fetch_string($key);
+    return exists $self->{$key} ? $self->{$key} : $self->fetch_string($key);
 }
+
 sub TIEHASH {
     bless $_[1], $_[0];
 }
@@ -73,26 +82,28 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/lib/perl/5.10',
+    archlibexp => '/usr/lib/perl/5.14',
     archname => 'x86_64-linux-gnu-thread-multi',
     cc => 'cc',
     d_readlink => 'define',
     d_symlink => 'define',
+    dlext => 'so',
     dlsrc => 'dl_dlopen.xs',
     dont_use_nlink => undef,
     exe_ext => '',
-    inc_version_list => '5.10.0',
+    inc_version_list => '',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib /lib /usr/lib /lib64 /usr/lib64',
+    libpth => '/usr/local/lib /lib/x86_64-linux-gnu /lib/../lib /usr/lib/x86_64-linux-gnu /usr/lib/../lib /lib /usr/lib',
     osname => 'linux',
-    osvers => '2.6.32-5-amd64',
+    osvers => '3.2.0-4-amd64',
     path_sep => ':',
-    privlibexp => '/usr/share/perl/5.10',
+    privlibexp => '/usr/share/perl/5.14',
     scriptdir => '/usr/bin',
-    sitearchexp => '/usr/local/lib/perl/5.10.1',
-    sitelibexp => '/usr/local/share/perl/5.10.1',
+    sitearchexp => '/usr/local/lib/perl/5.14.2',
+    sitelibexp => '/usr/local/share/perl/5.14.2',
+    so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.10.1',
+    version => '5.14.2',
 };
